pub struct CachedSource<T> { /* private fields */ }Expand description
It tries to reused cached results from other methods to avoid calculations, usually used after modify is finished.
use rustbolt_sources::{
BoxSource, CachedSource, ConcatSource, MapOptions, OriginalSource,
RawSource, Source, SourceExt, SourceMap,
};
let mut concat = ConcatSource::new([
RawSource::from("Hello World\n".to_string()).boxed(),
OriginalSource::new(
"console.log('test');\nconsole.log('test2');\n",
"console.js",
)
.boxed(),
]);
concat.add(OriginalSource::new("Hello2\n", "hello.md"));
let cached = CachedSource::new(concat);
assert_eq!(
cached.source(),
"Hello World\nconsole.log('test');\nconsole.log('test2');\nHello2\n"
);
// second time will be fast.
assert_eq!(
cached.source(),
"Hello World\nconsole.log('test');\nconsole.log('test2');\nHello2\n"
);Implementations