pub struct OriginalSource { /* private fields */ }Expand description
Represents source code, it will create source map for the source code,
but the source map is created by splitting the source code at typical
statement borders (;, {, }).
use rustbolt_sources::{OriginalSource, MapOptions, Source};
let input = "if (hello()) { world(); hi(); there(); } done();\nif (hello()) { world(); hi(); there(); } done();";
let source = OriginalSource::new(input, "file.js");
assert_eq!(source.source(), input);
assert_eq!(
source.map(&MapOptions::default()).unwrap().mappings(),
"AAAA,eAAe,SAAS,MAAM,WAAW;AACzC,eAAe,SAAS,MAAM,WAAW",
);
assert_eq!(
source.map(&MapOptions::new(false)).unwrap().mappings(),
"AAAA;AACA",
);Implementations